@@ -268,7 +268,6 @@ r_gtk_data_frame_get_column_type (GtkTreeModel *tree_model,
   g_return_val_if_fail (R_GTK_IS_DATA_FRAME (tree_model), G_TYPE_INVALID);
   g_return_val_if_fail (index < GET_LENGTH (R_GTK_DATA_FRAME (tree_model)->frame) &&
 			index >= 0, G_TYPE_INVALID);
-
   type = getSValueGType(VECTOR_ELT(data_frame->frame, index));
   return type;
 }
@@ -329,7 +328,6 @@ r_gtk_data_frame_get_value (GtkTreeModel *tree_model,
   g_return_if_fail (R_GTK_IS_DATA_FRAME (tree_model));
   g_return_if_fail (column < GET_LENGTH(R_GTK_DATA_FRAME (tree_model)->frame));
   g_return_if_fail (VALID_ITER (iter, R_GTK_DATA_FRAME(tree_model)));
-
   initGValueFromVector(VECTOR_ELT(data_frame->frame, column),
   	GPOINTER_TO_INT(iter->user_data), value);
 }
@@ -468,8 +466,9 @@ r_gtk_data_frame_set (RGtkDataFrame *data_frame,
 	R_PreserveObject(frame);
 	
 	data_frame->frame = frame;
-	data_frame->stamp = data_frame->stamp++;
-
+	data_frame->stamp = data_frame->stamp + 1;
+        data_frame->nrows = frame_nrows;
+        
 	for (i = 0; i < nrows; i++) {
 		gint row = changed_rows[i];
 		GtkTreePath *path = gtk_tree_path_new_from_indices(row, -1);
@@ -487,8 +486,6 @@ r_gtk_data_frame_set (RGtkDataFrame *data_frame,
   }
 	if (data_frame->sort_id != -1 && resort)
 		r_gtk_data_frame_resort(data_frame);
-  
-  data_frame->nrows = frame_nrows;
 }
 
 static void r_gtk_data_frame_set_sort_closure(RGtkDataFrame *frame, USER_OBJECT_ closure)
@@ -512,7 +509,7 @@ r_gtk_data_frame_remove (RGtkDataFrame *data_frame,
 	g_return_if_fail (frame != NULL);
 	
 	data_frame->frame = frame;
-	data_frame->stamp = data_frame->stamp++;
+	data_frame->stamp = data_frame->stamp + 1;
 	
 	for (i = 0; i < nrows; i++) {
 		GtkTreePath *path = gtk_tree_path_new_from_indices(deleted_rows[i], -1);
@@ -591,7 +588,7 @@ r_gtk_data_frame_set_sort_func (GtkTreeSortable        *sortable,
                                       gpointer                user_data,
                                       GtkDestroyNotify        destroy_func)
 {
-    g_warning ("%s is not supported by the RGtkDataModel model.\n", __FUNCTION__);
+    warning("gtk_tree_sortable_set_sort_func is not supported by the RGtkDataModel model.");
 }
 
 
@@ -601,7 +598,7 @@ r_gtk_data_frame_set_default_sort_func (GtkTreeSortable        *sortable,
                                               gpointer                user_data,
                                               GtkDestroyNotify        destroy_func)
 {
-    g_warning ("%s is not supported by the RGtkDataModel model.\n", __FUNCTION__);
+    warning("gtk_tree_sortable_set_default_sort_func is not supported by the RGtkDataModel model.");
 }
 
 
